@@ -322,7 +322,9 @@ load_thumbnail_frame (NautilusIconFactory *factory)
 	if (factory->thumbnail_frame != NULL) {
 		g_object_unref (factory->thumbnail_frame);
 	}
-	factory->thumbnail_frame = gdk_pixbuf_new_from_file (image_path, NULL);
+	if (image_path != NULL) {
+		factory->thumbnail_frame = gdk_pixbuf_new_from_file (image_path, NULL);
+	}
 	g_free (image_path);
 }
 
@@ -1198,6 +1200,10 @@ create_normal_cache_icon (const char *icon,
 		filename = gtk_icon_info_get_filename (info);
 	}
 
+	/* If e.g. the absolute filename doesn't exist */
+	if (filename == NULL) {
+		return NULL;
+	}
 	
 	pixbuf = load_icon_file (filename,
 				 base_size,
