@@ -378,16 +378,6 @@ update_up_button (NautilusWindow *window)
         nautilus_window_allow_up (window, allowed);
 }
 
-static void
-update_burn_cd_items (NautilusWindow *window)
-{
-        gboolean show_burn_cd;
-        
-        show_burn_cd = eel_istr_has_prefix (window->details->location, "burn:");
-
-        nautilus_window_allow_burn_cd (window, show_burn_cd);
-}
-
 static void
 viewed_file_changed_callback (NautilusFile *file,
                               NautilusWindow *window)
@@ -446,7 +436,7 @@ viewed_file_changed_callback (NautilusFile *file,
                                                            window->details->location)) {
                         g_free (window->details->location);
                         window->details->location = new_location;
-                        
+			
                         /* Check if we can go up. */
                         update_up_button (window);
 #if !NEW_UI_COMPLETE
@@ -456,6 +446,12 @@ viewed_file_changed_callback (NautilusFile *file,
                                         (NAUTILUS_NAVIGATION_BAR (NAUTILUS_NAVIGATION_WINDOW (window)->navigation_bar),
                                          window->details->location);
                         }                  
+                        if (NAUTILUS_IS_SPATIAL_WINDOW (window)) {
+                                /* Change the location button to match the current location. */
+                                nautilus_spatial_window_set_location_button
+                                        (NAUTILUS_SPATIAL_WINDOW (window),
+                                         window->details->location);
+                        }                  
 #endif
 
                 } else {
@@ -542,11 +538,11 @@ update_for_new_location (NautilusWindow *window)
         /* Check if we can go up. */
         update_up_button (window);
 
-        /* Check if we can go up. */
-        update_burn_cd_items (window);
-
         /* Set up the content view menu for this new location. */
         nautilus_window_load_view_as_menus (window);
+	
+	/* Load menus from nautilus extensions for this location */
+	nautilus_window_load_extension_menus (window);
       
 #if !NEW_UI_COMPLETE
         if (NAUTILUS_IS_NAVIGATION_WINDOW (window)) {
@@ -557,6 +553,8 @@ update_for_new_location (NautilusWindow *window)
                 /* Change the location bar to match the current location. */
                 nautilus_navigation_bar_set_location (NAUTILUS_NAVIGATION_BAR (NAUTILUS_NAVIGATION_WINDOW (window)->navigation_bar),
                                                       window->details->location);
+
+		nautilus_navigation_window_load_extension_toolbar_items (NAUTILUS_NAVIGATION_WINDOW (window));
         }
         
         /* Notify the information panel of the location change. */
@@ -570,6 +568,13 @@ update_for_new_location (NautilusWindow *window)
                                                     window->details->location,
                                                     window->details->title);
 	}
+
+	if (NAUTILUS_IS_SPATIAL_WINDOW (window)) {
+		/* Change the location button to match the current location. */
+		nautilus_spatial_window_set_location_button
+			(NAUTILUS_SPATIAL_WINDOW (window),
+			 window->details->location);
+	}                  
 #endif
 }
 
@@ -660,9 +665,20 @@ open_location (NautilusWindow *window,
         
         target_window = NULL;
 
-        switch (mode) {
+	switch (mode) {
         case Nautilus_ViewFrame_OPEN_ACCORDING_TO_MODE :
-                if (NAUTILUS_IS_SPATIAL_WINDOW (window)) {
+		if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER)) {
+			target_window = window;
+			if (NAUTILUS_IS_DESKTOP_WINDOW (window)) {
+				if (!NAUTILUS_SPATIAL_WINDOW (window)->affect_spatial_window_on_next_location_change) {
+					target_window = nautilus_application_create_navigation_window 
+						(window->application,
+						 gtk_window_get_screen (GTK_WINDOW (window)));
+				} else {
+					NAUTILUS_SPATIAL_WINDOW (window)->affect_spatial_window_on_next_location_change = FALSE;
+				}
+			}
+		} else if (NAUTILUS_IS_SPATIAL_WINDOW (window)) {
                         if (!NAUTILUS_SPATIAL_WINDOW (window)->affect_spatial_window_on_next_location_change) {
                                 target_window = nautilus_application_present_spatial_window (
                                         window->application,
