@@ -49,12 +49,11 @@
 #include <eel/eel-xml-extensions.h>
 #include <libxml/parser.h>
 #include <gtk/gtkmain.h>
-#include <libegg/egg-screen-help.h>
-#include <libegg/egg-screen-exec.h>
 #include <libgnome/gnome-help.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-util.h>
 #include <libgnomeui/gnome-about.h>
+#include <libgnomeui/gnome-help.h>
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomevfs/gnome-vfs-file-info.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
@@ -631,11 +630,11 @@ help_menu_nautilus_manual_callback (BonoboUIComponent *component,
 	window = NAUTILUS_WINDOW (user_data);
 
 	if (NAUTILUS_IS_DESKTOP_WINDOW (window)) {
-		egg_screen_execute_command_line_async (
+		gdk_spawn_command_line_on_screen (
 			gtk_window_get_screen (GTK_WINDOW (window)),
 			"gnome-help", &error);
 	} else {
-		egg_help_display_desktop_on_screen (
+		gnome_help_display_desktop_on_screen (
 			NULL, "user-guide", "user-guide.xml", "gosnautilus-21",
 			gtk_window_get_screen (GTK_WINDOW (window)), &error);
 	}
